function est = CentralEstimator(est,u,y,estModel)
% Centralized estimator update.  
% 
% Inputs:
%   est         estimator state struct
%   u           control input
%   y           measurement
%   estModel    system model as used for estimation
%
% --
% Supplementary material (simulation examples) to:
%   Distributed Event-based State Estimation (technical report)
%   Event-based State Estimation: An Emulation-based Approach (journal)
%
% Copyright 2015-17 Max Planck Society. All rights reserved.
% 
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [10.04.15]   first version


% Estimation: Prediction
if estModel.flagReducedModel
    % reduced model
    xpred =     estModel.A * est.xhat + ...
                estModel.B * u + ...
                estModel.Bminus * est.u_minus;
    est.u_minus = u;  % keep for next step
else
    xpred =     estModel.A * est.xhat + ...
                estModel.B * u;
    % agent.uhat_minus not needed; don't update
end;


% Estimation: Measurement update
est.xhat = xpred + est.L*(y - estModel.C*xpred);


% Full estimate
if estModel.flagReducedModel
    est.xhat_full = [est.xhat(1:estModel.n_u); est.u_minus; est.xhat((estModel.n_u+1):end)];
else
    est.xhat_full = est.xhat;
end;